<?php

namespace Drupal\webfactory_master\PageCache;

use Drupal\Core\PageCache\ResponsePolicyInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Cache policy for channel rest page.
 *
 * This policy rule denies caching of responses generated by the
 * rest /webfactory_master/channel routes.
 */
class DenyChannelCache implements ResponsePolicyInterface {

  /**
   * Dynamic route root built by rest module to disable the cache.
   */
  const WEBFACTORY_MASTER_ROUTE_ROOT = 'rest.webfactory_master.channel';

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * Constructs a deny node preview page cache policy.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The current route match.
   */
  public function __construct(RouteMatchInterface $route_match) {
    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public function check(Response $response, Request $request) {
    if (strstr($this->routeMatch->getRouteName(), static::WEBFACTORY_MASTER_ROUTE_ROOT)) {
      return static::DENY;
    }
    return NULL;
  }

}
